@@ -2,4 +2,4 @@
 
 from __future__ import absolute_import
 
-from . import apps, base, bookings, projects, resources
\ No newline at end of file
+from . import apps, base, bookings, projects, resources, availability
\ No newline at end of file
